import { subjectDetail } from "@/api";

const firstRoutes = {
  ADMIN: "WorkManage",
  MARKER_LEVEL: "MarkerGrading",
  MARKER_SCORE: "MarkerMarking",
  MARK_LEADER_LEVEL: "LeaderGrading",
  MARK_LEADER_SCORE: "LeaderMarking",
  INSPECTION: "Inspection",
  QC: "Quality",
};
const levelStages = ["LEVEL", "ROUGH_LEVEL"];
const markRoles = ["MARKER", "MARK_LEADER"];

export async function getFirstRoute(userData) {
  const { workId, subject, role } = userData;
  let routerType = role;
  if (markRoles.includes(routerType)) {
    const subjectId = `${workId}-${subject}`;
    const curSubject = await subjectDetail(subjectId);

    const mRes = checkMarkValid(userData, curSubject.stage);
    if (!mRes.valid) {
      return mRes;
    }

    const stage = levelStages.includes(curSubject.stage)
      ? "LEVEL"
      : curSubject.stage;
    routerType = `${role}_${stage}`;
  }

  const routerName = firstRoutes[routerType];
  return {
    valid: true,
    data: routerName,
  };
}

export function checkMarkValid(userData, stage, pageStage = "") {
  const { role, markRight } = userData;

  const nStage = levelStages.includes(stage) ? "LEVEL" : stage;

  if (nStage === "INIT") {
    return {
      valid: false,
      message: "当前工作未开启分档！",
    };
  }
  if (role === "MARKER") {
    if (
      (nStage === "LEVEL" && markRight === "ALLOW_SCORING") ||
      (nStage === "SCORE" && markRight === "ALLOW_LEVELING")
    ) {
      return {
        valid: false,
        message: "您的权限不够！",
      };
    }
  }

  if (pageStage && nStage !== pageStage) {
    return {
      valid: false,
      message: "阶段错误！",
    };
  }

  return {
    valid: true,
  };
}
